# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['dfa_mutate']

package_data = \
{'': ['*']}

install_requires = \
['dfa>=4.6.3,<5.0.0']

setup_kwargs = {
    'name': 'dfa-mutate',
    'version': '0.1.2',
    'description': 'Library for mutating a DFA represented using the dfa library.',
    'long_description': '# DFA Mutate\n\nPrimitives and utilities for manipulating deterministic finite automata (DFA) represented using the [dfa](https://github.com/mvcisback/dfa) library.\n\n[![Build Status](https://cloud.drone.io/api/badges/mvcisback/dfa_mutate/status.svg)](https://cloud.drone.io/mvcisback/dfa_mutate)\n[![PyPI version](https://badge.fury.io/py/dfa_mutate.svg)](https://badge.fury.io/py/dfa_mutate)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n\n**Table of Contents**\n\n- [Installation](#installation)\n- [Usage](#usage)\n\n\n Installation\n\nIf you just need to use `dfa_mutate`, you can just run:\n\n`$ pip install dfa_mutate`\n\nFor developers, note that this project uses the\n[poetry](https://poetry.eustace.io/) python package/dependency\nmanagement tool. Please familarize yourself with it and then\nrun:\n\n`$ poetry install`\n\n# Usage\n\n**Example Usage:**\n```python\nfrom dfa import DFA\nimport dfa_mutate\n\ndfa1 = DFA(\n    start=0,\n    inputs={0, 1},\n    label=lambda s: (s % 4) == 3,\n    transition=lambda s, c: (s + c) % 4,\n)\n\n# Pick a specific mutation.\ndfa2 = dfa_mutate.add_state(dfa1)\ndfa3 = dfa_mutate.change_start(dfa1)\ndfa4 = dfa_mutate.change_transition(dfa1)\ndfa5 = dfa_mutate.relabel_state(dfa1)\n\n# Infinite Generator mutations round-robin (will repeat).\ndfas = dfa_mutate.generate_mutations(orig)\n\n# Sample DFA using softmax over a scoring function (default constant).\n# Uses first n dfas generated by above generator.\n\n# NOTE: requires the optional numpy dependency.\ndfa6 = dfa_mutate.sample_mutation(dfa1, n=20, score=lambda d: len(d.states()))\n\n# All functions support passing in random number generator.\nimport random\ndfa7 = dfa_mutate.relabel_state(dfa1, random.Random(0))\n```\n\n',
    'author': 'Marcell Vazquez-Chanlatte',
    'author_email': 'mvc@linux.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/mvcisback/dfa-mutate',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
